@@ -9,3 +9,10 @@ from ._member import member
 from ._meta import StructureMeta
 from ._sized_member import sized_member
 from ._structure import Structure
+
+bitfield_member.__module__ = "plum.structure"
+dimmed_member.__module__ = "plum.structure"
+member.__module__ = "plum.structure"
+StructureMeta.__module__ = "plum.structure"
+sized_member.__module__ = "plum.structure"
+Structure.__module__ = "plum.structure"
